<?php
/**
 * Gutenberg Editor CSS
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package     Craftsandarts
 * @author      Craftsandarts
 * @copyright   Copyright (c) 2019, Craftsandarts
 * @link        http://themes-demo.com/craftsandarts/
 * @since       Craftsandarts 1.0
 */

if ( ! class_exists( 'Gutenberg_Editor_CSS' ) ) :
	/**
	 * Admin Helper
	 */
	class Gutenberg_Editor_CSS {

		function __construct() {

			add_action('after_setup_theme', array( $this,  'craftsandarts_after_setup_theme' ) );

			add_action( 'current_screen', array( $this,  'craftsandarts_current_screen_hook' ), 10, 1 );
			add_action( 'enqueue_block_editor_assets', array( $this, 'craftsandarts_backend_editor_styles' ), 10 );
			if ( class_exists( 'Classic_Editor' ) ) {
				add_filter( 'tiny_mce_before_init', array( $this, 'craftsandarts_theme_editor_dynamic_styles' ) );
			}

			add_action( 'wp_enqueue_scripts', array( $this, 'craftsandarts_editor_enqueue_styles'), 110 );

		}

		public function craftsandarts_after_setup_theme() {

			# Gutenberg Compatible
			add_theme_support( 'align-wide' );
			add_theme_support( 'wp-block-styles' );
			add_theme_support( 'editor-styles' );
				
			# Add support for responsive embedded content.
			add_theme_support( 'responsive-embeds' );

			$primary_color = $secondary_color = $tertiary_color = '';
			$skin = craftsandarts_option('colors', 'theme-skin');
			$skin = ($skin != '') ? $skin : 'skyblue';

			if( $skin == 'custom' ) {
				$default_options = craftsandarts_default_option();
				$custom_default = $default_options['colors']['custom-default'];
				$custom_light = $default_options['colors']['custom-light'];
				$custom_dark = $default_options['colors']['custom-default'];

				$primary_color   = craftsandarts_opts_get('custom-default', $custom_default);
				$secondary_color = craftsandarts_opts_get('custom-light', $custom_light);
				$tertiary_color  = craftsandarts_opts_get('custom-dark', $custom_dark);
			} else {
				$colors          = $this->craftsandarts_skins( $skin );
				$primary_color   = $colors['primary-color'];
				$secondary_color = $colors['secondary-color'];
				$tertiary_color  = $colors['tertiary-color'];
			}

			add_theme_support( 'editor-color-palette', array(
				array(
					'name'  => esc_html__( 'Primary Color', 'crafts-and-arts' ),
					'slug'  => 'primary',
					'color' => $primary_color,
				),
				array(
					'name'  => esc_html__( 'Secondary Color', 'crafts-and-arts' ),
					'slug'  => 'secondary',
					'color' => $secondary_color,
				),
				array(
					'name'  => esc_html__( 'Tertiary Color', 'crafts-and-arts' ),
					'slug'  => 'tertiary',
					'color' => $tertiary_color,
				)
			));

		}

		public function craftsandarts_skins( $skin ) {

			$skins['antiquewhite'] = array( 'primary-color' => '#fae3dc', 'secondary-color' => '#f1cbbf', 'tertiary-color' => '#fcf4f2');
			$skins['applegreen']   = array( 'primary-color' => '#b8dc3c', 'secondary-color' => '#93b520', 'tertiary-color' => '#dee8bc');
			$skins['blue']         = array( 'primary-color' => '#008bd3', 'secondary-color' => '#0081c2', 'tertiary-color' => '#cce5f2');
			$skins['brown']        = array( 'primary-color' => '#795548', 'secondary-color' => '#573a30', 'tertiary-color' => '#ccc3c0');
			$skins['cadetblue']    = array( 'primary-color' => '#3c939d', 'secondary-color' => '#34818a', 'tertiary-color' => '#c2d9db');
			$skins['chillipepper'] = array( 'primary-color' => '#c10841', 'secondary-color' => '#9d0836', 'tertiary-color' => '#e1b4c2');
			$skins['cyan']         = array( 'primary-color' => '#00bcd4', 'secondary-color' => '#00a0b4', 'tertiary-color' => '#b2e2e8');
			$skins['darkgolden']   = array( 'primary-color' => '#b48b3c', 'secondary-color' => '#a17b35', 'tertiary-color' => '#e2d7c2');
			$skins['deeporange']   = array( 'primary-color' => '#ff5722', 'secondary-color' => '#db4211', 'tertiary-color' => '#f4c6b7');
			$skins['deeppurple']   = array( 'primary-color' => '#673ab7', 'secondary-color' => '#532b99', 'tertiary-color' => '#cbbfe0');
			$skins['green']        = array( 'primary-color' => '#60ae0d', 'secondary-color' => '#54990b', 'tertiary-color' => '#cbe0b5');
			$skins['indigo']       = array( 'primary-color' => '#571F9C', 'secondary-color' => '#461286', 'tertiary-color' => '#c7b7da');
			$skins['lightgreen']   = array( 'primary-color' => '#9bff87', 'secondary-color' => '#8ee97c', 'tertiary-color' => '#ddf8d7');	
			$skins['lightpurple']  = array( 'primary-color' => '#9d90de', 'secondary-color' => '#735edc', 'tertiary-color' => '#d5cef4');
			$skins['lime']         = array( 'primary-color' => '#cddc39', 'secondary-color' => '#b1bf27', 'tertiary-color' => '#eff2d3');
			$skins['limeyellow']   = array( 'primary-color' => '#ffea18', 'secondary-color' => '#ebd920', 'tertiary-color' => '#f9f3bc');
			$skins['magenta']      = array( 'primary-color' => '#cb506d', 'secondary-color' => '#ae3753', 'tertiary-color' => '#e6c3cb');
			$skins['orange']       = array( 'primary-color' => '#ff9800', 'secondary-color' => '#da8200', 'tertiary-color' => '#f3d9b2');
			$skins['palegreen']    = array( 'primary-color' => '#aef801', 'secondary-color' => '#a5e313', 'tertiary-color' => '#e4f6b8');
			$skins['pink']         = array( 'primary-color' => '#fd6ca3', 'secondary-color' => '#e86496', 'tertiary-color' => '#fae0ea'); 
			$skins['purple']       = array( 'primary-color' => '#9c27b0', 'secondary-color' => '#7c1b8c', 'tertiary-color' => '#d7badc');
			$skins['red']          = array( 'primary-color' => '#da0000', 'secondary-color' => '#c50000', 'tertiary-color' => '#f3cccc');
			$skins['seagreen']     = array( 'primary-color' => '#19dd89', 'secondary-color' => '#29b579', 'tertiary-color' => '#d4f0e4');
			$skins['skyblue']      = array( 'primary-color' => '#0eb2e7', 'secondary-color' => '#0da2d4', 'tertiary-color' => '#ceecf6');
			$skins['skybluelight'] = array( 'primary-color' => '#9bf0e9', 'secondary-color' => '#8ddad4', 'tertiary-color' => '#e8f7f6');
			$skins['teal']         = array( 'primary-color' => '#009688', 'secondary-color' => '#007f73', 'tertiary-color' => '#cce5e3');
			$skins['turquoise']    = array( 'primary-color' => '#32ccbd', 'secondary-color' => '#24b6a8', 'tertiary-color' => '#d3f0ed');
			$skins['violetred']    = array( 'primary-color' => '#d31996', 'secondary-color' => '#a8257d', 'tertiary-color' => '#edd3e5');
			$skins['wisteria']     = array( 'primary-color' => '#9b59b6', 'secondary-color' => '#7c4094', 'tertiary-color' => '#e4d8e9');
			$skins['yellow']       = array( 'primary-color' => '#ffc107', 'secondary-color' => '#ebd302', 'tertiary-color' => '#f9f1b3');

			return $skins[ $skin ];
	
		}

		public function craftsandarts_current_screen_hook( $current_screen ) {
			
			if ( 'post' == $current_screen->base ) {

				$google_fonts = craftsandarts_fonts();
				$google_fonts = $google_fonts['all'];

				$subset = craftsandarts_option('fonts', 'font-subset');
				if( $subset ) $subset = str_replace(' ', '', $subset);
				$subset = isset($subset) && !empty($subset) ? $subset : '';

				if( $weight = craftsandarts_option('fonts', 'font-style') )
					$weight = ':'. implode( ',', $weight );

				$fonts = craftsandarts_fonts_selected();
				$fonts = array_unique($fonts);
				$fonts_url = ''; $font_families = array('Marck Script');
				foreach( $fonts as $font ){
					if( in_array( $font, $google_fonts ) ){
						$font_families[] .= $font . $weight;
					}
				}
				$query_args = array( 'family' => urlencode( implode( '|', $font_families ) ), 'subset' => urlencode( $subset ) );
				$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );

				add_editor_style( $fonts_url );
				add_editor_style( 'css/editor-style.css' );

			}

		}

		public function craftsandarts_generate_editor_styles( $editor_type = 'block' ) {
			
			if($editor_type == 'tinymce') {
				$wrapper_class = 'body#tinymce.wp-editor.content';
				$header_wrapper_class = $wrapper_class;
				$header1_add_class = '';
			} else {
				$wrapper_class = '.editor-styles-wrapper';
				$header_wrapper_class = $wrapper_class.' .wp-block';
				$header1_add_class = '.editor-post-title__block .editor-post-title__input, ';
			}
			

			$styles = '';

			$styles .= $wrapper_class.' pre { font-family:monospace; }';


			$styles .= $wrapper_class.' > * { ';

				$content_font = craftsandarts_option('fonts', 'content-font');
				if( $content_font != '' ) {
					$styles .= 'font-family: '.$content_font.';';
				}

				$content_font_size = craftsandarts_option('fonts', 'content-font-size');
				if( $content_font_size != '' ) {
					$styles .= 'font-size: '.$content_font_size.'px;';
				}

				$body_line_height = craftsandarts_option('fonts', 'body-line-height');
				if( $body_line_height != '' ) {
					$styles .= 'line-height: '.$body_line_height.'px;';
				}

			$styles .= ' }';


			$body_bg_color = craftsandarts_option('colors', 'body-bgcolor');
			if( $body_bg_color != '' ) {
				$styles .= $wrapper_class.' { background-color: '.$body_bg_color.'; } ';
			}

			$content_text_color = craftsandarts_option('colors', 'content-text-color');
			if( $content_text_color != '' ) {
				$styles .= $wrapper_class.' > *, '.$wrapper_class.' pre { color: '.$content_text_color.'; } ';
			}

			$content_link_color = craftsandarts_option('colors', 'content-link-color');
			if( $content_link_color != '' ) {
				$styles .= $wrapper_class.' a { color: '.$content_link_color.'; } ';
			}

			$content_link_hcolor = craftsandarts_option('colors', 'content-link-hcolor');
			if( $content_link_hcolor != '' ) {
				$styles .= $wrapper_class.' a:focus, '.$wrapper_class.' a:hover { color: '.$content_link_hcolor.'; } ';
			}


			for( $i = 1; $i <= 6; $i++ ) {

				if($i == 1) {
					$header_wrapper_final_class = $header1_add_class.$header_wrapper_class;
				} else {
					$header_wrapper_final_class = $header_wrapper_class;
				}

				$styles .= $header_wrapper_final_class.' h'.$i.' { ';

					$heading_color = craftsandarts_option('colors', 'heading-h'.$i.'-color');
					if( $heading_color != '' ) {
						$styles .= 'color: '.$heading_color.';';
					}

					$heading_font = craftsandarts_option('fonts', 'h'.$i.'-font');
					if( $heading_font != '' ) {
						$styles .= 'font-family: '.$heading_font.';';
					}

					$heading_font_size = craftsandarts_option('fonts', 'h'.$i.'-font-size');
					if( $heading_font_size != '' ) {
						$styles .= 'font-size: '.$heading_font_size.'px;';
					}

					$heading_font_weight = craftsandarts_option('fonts', 'h'.$i.'-weight');
					if( $heading_font_weight != '' ) {
						$styles .= 'font-weight: '.$heading_font_weight.';';
					}

					$heading_letter_spacing = craftsandarts_option('fonts', 'h'.$i.'-letter-spacing');
					if( $heading_letter_spacing != '' ) {
						$styles .= 'letter-spacing: '.$heading_letter_spacing.';';
					}

				$styles .= ' }';

			}
			
			return $styles;

		}

		public function craftsandarts_backend_editor_styles() {
			
			wp_enqueue_style( 'craftsandarts-gutenberg', get_theme_file_uri('/css/admin-gutenberg.css'), false, CRAFTSANDARTS_THEME_VERSION, 'all' );
			wp_add_inline_style( 'craftsandarts-gutenberg', craftsandarts_styles_custom_font() );
						
			$styles = $this->craftsandarts_generate_editor_styles('block');
			
			wp_add_inline_style( 'craftsandarts-gutenberg', $styles );

		}
			
		public function craftsandarts_theme_editor_dynamic_styles( $mceInit ) {

			$styles = craftsandarts_styles_custom_font();

			$styles .= $this->craftsandarts_generate_editor_styles('tinymce');

			if ( isset( $mceInit['content_style'] ) ) {
				$mceInit['content_style'] .= ' ' . $styles . ' ';
			} else {
				$mceInit['content_style'] = $styles . ' ';
			}
			
			return $mceInit;
		}

		public function craftsandarts_editor_enqueue_styles( ) {

			$styles = '';

			$primary_color = $secondary_color = $tertiary_color = '';
			$skin = craftsandarts_option('colors', 'theme-skin');
			$skin = ($skin != '') ? $skin : 'skyblue';
	
			if( $skin == 'custom' ) {
				$default_options = craftsandarts_default_option();
				$custom_default = $default_options['colors']['custom-default'];
				$custom_light = $default_options['colors']['custom-light'];
				$custom_dark = $default_options['colors']['custom-default'];
	
				$primary_color   = craftsandarts_opts_get('custom-default', $custom_default);
				$secondary_color = craftsandarts_opts_get('custom-light', $custom_light);
				$tertiary_color  = craftsandarts_opts_get('custom-dark', $custom_dark);
			} else {
				$colors          = $this->craftsandarts_skins( $skin );
				$primary_color   = $colors['primary-color'];
				$secondary_color = $colors['secondary-color'];
				$tertiary_color  = $colors['tertiary-color'];
			}

			# Primary Color
			$styles .= '.has-primary-background-color { background-color:'.$primary_color.'; }';
			$styles .= '.has-primary-color { color:'.$primary_color.'; }';
	
			# Secondary Color
			$styles .= '.has-secondary-background-color { background-color:'.$secondary_color.'; }';
			$styles .= '.has-secondary-color { color:'.$secondary_color.'; }';
	
			# Tertiary Color
			$styles .= '.has-tertiary-background-color { background-color:'.$tertiary_color.'; }';
			$styles .= '.has-tertiary-color { color:'.$tertiary_color.'; }';

			wp_add_inline_style('craftsandarts-gutenberg', $styles );

		}

	}

	new Gutenberg_Editor_CSS();

endif;